$lines
     remark  program LOAN(input = CRT, output = CRT,PROWRITER)

	comment
	   This is a program used to compute loan payments.  It assumes
	   that payments occur at  the beginning of the period.  The 
	   program was written in Structured Basic by Jeff Brown.
	   Version nos. for the software are:

	      CP/M  2.2
	      S-Basic v5.4b, document revision 4.0 for KayPro II
	      Perfect Writer 1.20

	   The function of the Loan Calculator is to solve one of the
	   three loan types: 

	      Principal and Interest paid as lump sum at end

	      Interest payments with Principal paid at end

	      Both Principal and Interest payments with or without a
	      balloon payment at the end.

	   The basic formulas used to calculate these loans are:

	                                           1 - (1 + r/n)**(mn)
	      Withdrawing from Annuity   A = S * -----------------------
	      (not contin. compounding)           1 - (1 + r/n)**(-n/N)

	              or
	                                           1 - e**(rm)
	      Withdrawing from Annuity   A = S * ---------------
	      (continuous compounding)            1 - e**(-r/N)

	   where A is the present value (loan amount), S is the payment
	   withdrawal amount (loan periodic payment), r is the interest
	   rate, m is the number of years, n is the interest compounding 
	   period, and N is the number of payments per year (period).  
	   Note that e stands for the natural logarithm.

	      Discrete Compounding        V = A * (1.0 + r/n)**mn

	      Continuous Compounding      V = A * e**(rm)

	   where V is the final amount (current value of loan), A is the
	   initial amount (last value of loan), r is the interest rate
	   (a decimal fraction), n is the number of compounding periods
	   per year, and m is the number of years.  Note that e stands
	   for the value 2.71828...

	   The first two loan types are calculated using the compounding 
	   formulas.  The last is a piecewise function where the calculations
	   are as follows:

	      Calculate the interest for the balloon over the period using
	      the compound interest formula

	      Calculate the increase in value of the loan principal (less
	      the balloon) for one period using the compound interest formula

	      Calculate the periodic payments using the annuity formula on 
	      the new loan principal and then add the balloon payment interest

	   This gives the amount of the periodic payment.  Then the division
	   of interest and principal out of this amount is calculated using
	   the compound interest formulas for each period.
	end of comment


	$constant  CRT = 0		;logical device, 0 = con:
	$constant  PROWRITER = 1	;logical device, 1 = lpt:
	$constant  SEND.BEEP = 07	;ascii code for bell
	$constant  FALSE = 0		;logical statement false
	$constant  TRUE = 0FFFFH	;logical statement true
	$constant  DELAY = 2000		;loop count for screen refresh holdoff
	$constant  MAX.ARRAY.SIZE = 999	;size allowed for periodic payments

	var  CALC.SELECTION		;calculation type selected
	     PERIOD.CHAR		;period character selected
	        = char
	var  PERIOD			;period value selected
	        = real.double
	var  MONEY.PRINT.FORMAT ;printing format of monetary output
	     RATE.PRINT.FORMAT	;printing format of percentage output
	     YEARS.PRINT.FORMAT	;printing format of number of years output
	        = string:20
	var  TABLE.HEADER	;payment table header
	     TABLE.LINE.FORMAT	;printing format used to print a line in the payment table
	     PAYMENT.NUMBER.FORMAT ;printing format of payment number
	     REQUEST.NUMBER.FORMAT ;printing format used to get payment number
	        = string:90

	MONEY.PRINT.FORMAT = "$$#,###,###,###.##"
	RATE.PRINT.FORMAT = "####.##%"
	YEARS.PRINT.FORMAT = "####.## years\."
	PAYMENT.NUMBER.FORMAT = "Calculating payment number #### out of ####"
	REQUEST.NUMBER.FORMAT = "Enter PAYMENT NUMBER you wish to view (between 1 and ###) "
	TABLE.HEADER = " PAYMENT         AMOUNT          INTEREST         PRINCIPAL           BALANCE"
	TABLE.LINE.FORMAT = "   ###   $$###,###,###.##  $$###,###,###.##  $$###,###,###.##  $$###,###,###.##"


$list
	$include PRIMLIB HOME.AND.CLEAR.SCREEN
	$include PRIMLIB CHECK.VALID.CHAR
	$include PRIMLIB CHECK.VALID.REAL.NUMBER
	$include PRIMLIB CHECK.VALID.INTEGER.NUMBER
	$include PRIMLIB CONVERT.LOWER.TO.UPPER
	$include PRIMLIB INVALID.INPUT
	$include PRIMLIB RETURN.TO.MAIN.MENU
	$include GRAPHICS POSITION.CURSOR
	$include GRAPHICS CLEAR.TO.END.OF.SCREEN
$list


	procedure INTRO.TO.LOAN
	   comment
	      This module prints an introduction to the LOAN
	      Program.
	   end of comment

	   HOME.AND.CLEAR.SCREEN
	   print #CRT; "Welcome to the Loan Payment Calculator"
	   print #CRT; "How can I help you?"
	   print #CRT

	end of INTRO.TO.LOAN


	function GET.CALCULATION.SELECTION = char
	   comment
	      This module prints the menu selection available to the user
	      and then gets his response.
	   end of comment

	   var  THE.SELECTION	;user's character response to menu
	           = char
	   var  I		;loop index
	           = integer

	   text CRT,&
	If you can provide me with some information, I can
	calculate the following loan types for you:

	   <L>ump sum - total interest and principal are due at the
	        end of the loan period.
	   <I>nterest only - periodic interest payments are made and
	        the princial is paid  at the end of the loan period.
	   <P>rincipal and Interest - periodic payments of interest
	        and a portion of the principal.  A balloon payment
	        at the end of the load period is optional.

	Just type your selection below or type <E> to exit.
	&
	   remark  turn off auto echo of user input
	   echo off

	   input1 #CRT; "Selection"; THE.SELECTION

	   remark  turn on auto echo of user input
	   echo on

	   THE.SELECTION = CONVERT.LOWER.TO.UPPER(THE.SELECTION)
	   if not CHECK.VALID.CHAR("PILEPILEPI",THE.SELECTION)  then  THE.SELECTION = 'N'
	   case THE.SELECTION of
	      'N':  begin
	               remark  invalid entry
	               HOME.AND.CLEAR.SCREEN
	               INVALID.INPUT 'M'
	            end of case 'N'
	      'L':  print #CRT; "Lump Sum"
	      'I':  print #CRT; "Interest Only"
	      'P':  print #CRT; "Principal and Interest"
	      'E':  print #CRT; "Exit"
	   end of case THE.SELECTION
	   if (THE.SELECTION <> 'N')  then
	      begin
	         for I = 1 to DELAY	remark  wait loop
	         next I
	         HOME.AND.CLEAR.SCREEN
	      end of if-then

	end = THE.SELECTION

	procedure PRINT.PERIOD(PRINT.DEVICE = integer; THE.SELECTION = char)
	   comment
	      This primitive translates the period character into the
	      full word and prints it.
	   end of comment

	   case THE.SELECTION of
	      'N':  remark  error, do nothing
	      'C':  print #PRINT.DEVICE; "Continuous"
	      'D':  print #PRINT.DEVICE; "Daily"
	      'W':  print #PRINT.DEVICE; "Weekly"
	      'M':  print #PRINT.DEVICE; "Monthly"
	      'Q':  print #PRINT.DEVICE; "Quarterly"
	      'S':  print #PRINT.DEVICE; "Semiannually"
	      'Y':  print #PRINT.DEVICE; "Yearly"
	      'E':  print #PRINT.DEVICE; "Exit"
	   end of case THE.SELECTION

	end of PRINT.PERIOD


	function GET.PERIOD.SELECTION = char
	   comment
	      This module gets the user's period selection.
	   end of comment

	   var  THE.SELECTION	;user's character response to menu
	           = char
	   var  I		;loop index
	           = integer

	   text CRT,&
	Which type of interest compounding period will the loan have?

	   <C>ontinuous
	   <D>aily
	   <W>eekly
	   <M>onthly
	   <Q>uarterly
	   <S>emiannually
	   <Y>early

	Type your selection below or type <E> to exit from this menu.
	&
	   remark  turn off auto echo of user input
	   echo off

	   input1 #CRT; "Selection"; THE.SELECTION

	   remark  turn on auto echo of user input
	   echo on

	   THE.SELECTION = CONVERT.LOWER.TO.UPPER(THE.SELECTION)
	   if not CHECK.VALID.CHAR("CDWMQSYECD",THE.SELECTION)  then
	         begin
	            remark  indicate error
	            THE.SELECTION = 'N'
	            HOME.AND.CLEAR.SCREEN
	            INVALID.INPUT 'M'
	         end
	      else
	         begin
	            PRINT.PERIOD  CRT, THE.SELECTION
	            for I = 1 to DELAY	remark  wait loop
	            next I
	            HOME.AND.CLEAR.SCREEN
	         end of if-then-else
	
	end = THE.SELECTION


	function PERIOD.VALUE = real.double
	   comment
	      This primitive translates the period character into a numeric
	      value
	   end of comment

	   var  THE.VALUE		;period value
	           = real.double

	   case PERIOD.CHAR of
	      'N':  INVALID.INPUT 'G'
	      'C':  begin
	               remark  period is continuous, just set to zero
	               THE.VALUE = 0.0
	            end of case 'C'
	      'D':  begin
	               remark  period is daily
	               THE.VALUE = 365.0
	            end of case 'D'
	      'W':  begin
	               remark  period is weekly
	               THE.VALUE = 52.0
	            end of case 'W'
	      'M':  begin
	               remark  period is monthly
	               THE.VALUE = 12.0
	            end of case 'M'
	      'Q':  begin
	               remark  period is quarterly
	               THE.VALUE = 4.0
	            end of case 'Q'
	      'S':  begin
	               remark  period is semiannually
	               THE.VALUE = 2.0
	            end of case 'S'
	      'Y':  begin
	               remark  period is annually
	               THE.VALUE = 1.0
	            end of case 'Y'
	      'E':  INVALID.INPUT 'G'
	   end of case PERIOD.CHAR

	end = THE.VALUE


	function GET.REAL(PROMPT=char;LOWER.BOUND,UPPER.BOUND=real.double)=real.double
	   comment
	      This primitive gets a real number from the user and checks
	      is against a boundary set.  One exception is the 'T' case
	      where an whole real number is desired.
	   end of comment

	   var  THE.NUMBER	;number gotten from user
	           = real.double
	   var  AN.INTEGER	;used to get a whole number from the user
	        INPUT.IS.OK	;logical variable holding input check result
	           = integer

	   if not(CHECK.VALID.CHAR("PRTYBPRTYB",PROMPT))  then
	      INVALID.INPUT 'G'

	   repeat
	      begin
	         case PROMPT of
	            'B':  input1 #CRT; "        How much will the balloon payment be (0 if none)"; THE.NUMBER
	            'P':  input1 #CRT; "        How much is to be borrowed"; THE.NUMBER
	            'R':  input1 #CRT; "        What is the interest rate (i.e. 5, 8.5 ...)"; THE.NUMBER
	            'T':  begin
	                     input1 #CRT; "        How many payment periods per year (whole number 1 to 365)"; AN.INTEGER
	                     THE.NUMBER = AN.INTEGER
	                  end of 'T'
	            'Y':  input1 #CRT; "        What is the life of the loan"; THE.NUMBER
	         end of case PROMPT

	         INPUT.IS.OK = CHECK.VALID.REAL.NUMBER(LOWER.BOUND,UPPER.BOUND,THE.NUMBER)
	         if not INPUT.IS.OK  then  INVALID.INPUT 'R'
	      end
	   until  INPUT.IS.OK

	   print #CRT

	end = THE.NUMBER
   

	procedure CALC.INTEREST.PRINCIPAL.AT.END
	   comment
	      This module calculates the lump sum due at the end of the loan.
	      The sum consists of the principal and the accumulated interest.
	      Interest also accumulates interest during the loan period.
	   end of comment


	   var  PAYMENT			;
	        PRINCIPAL		;
	        INTEREST.RATE		;
	        LIFE.OF.LOAN		;
	           = real.double

	   print #CRT; "Loan Payment Calculator invoking Lump Sum formula"
	   print #CRT

	   print #CRT; "        The interest compounding period is ";
	   PRINT.PERIOD  CRT, PERIOD.CHAR
	   print #CRT

	   PRINCIPAL = GET.REAL('P',0.0,100000000.00)
	   INTEREST.RATE = GET.REAL('R',0.0,1000.00) / 100.0
	   LIFE.OF.LOAN = GET.REAL('Y',0.0,1000.00)

	   remark  The Payment is computed using one formula for
	   remark  discrete compounding (Period char <> C) and another for
	   remark  continuous compounding

	   if ( PERIOD.CHAR <> 'C' )  then  PAYMENT = PRINCIPAL * (1.0 + INTEREST.RATE / PERIOD) ** (LIFE.OF.LOAN * PERIOD)
	      else  PAYMENT = PRINCIPAL * exp(INTEREST.RATE * LIFE.OF.LOAN)

	   print #CRT
	   print #CRT; "        The FINAL PAYMENT is ";
	   print using MONEY.PRINT.FORMAT; #CRT; PAYMENT
	   print #CRT; "        The INTEREST PAID is ";
	   print using MONEY.PRINT.FORMAT; #CRT; (PAYMENT - PRINCIPAL)
	   print #CRT

	   RETURN.TO.MAIN.MENU

	end of CALC.INTEREST.PRINCIPAL.AT.END


	procedure CALC.INTEREST.LUMP.PRINCIPAL
	   comment
	      This module calculates the periodic interest payment due.  The
	      principal is paid in full at the end of the loan period.
	   end of comment

	   var  PAYMENT			;
	        PRINCIPAL		;
	        INTEREST.RATE		;
	        LIFE.OF.LOAN		;
	        TRANSACTIONS		;
	           = real.double

	   print #CRT; "Loan Payment Calculator invoking Lump Sum formula"
	   print #CRT

	   print #CRT; "        The interest compounding period is ";
	   PRINT.PERIOD  CRT, PERIOD.CHAR
	   print #CRT

	   PRINCIPAL = GET.REAL('P',0.0,100000000.00)
	   INTEREST.RATE = GET.REAL('R',0.0,1000.00) / 100.0
	   LIFE.OF.LOAN = GET.REAL('Y',0.0,1000.00)
	   TRANSACTIONS = GET.REAL('T',1.0,365.0)

	   remark  The Interest Payment is computed using one formula for
	   remark  discrete compounding (Period char <> C) and another for
	   remark  continuous compounding

	   if ( PERIOD.CHAR <> 'C' )  then  PAYMENT = PRINCIPAL * (-1.0 + (1.0 + INTEREST.RATE / PERIOD)**(PERIOD / TRANSACTIONS))
	      else  PAYMENT = PRINCIPAL * (-1.0 + exp(INTEREST.RATE / TRANSACTIONS))

	   print #CRT
	   print #CRT; "        The INTEREST PAYMENTS are  ";
	   print using MONEY.PRINT.FORMAT; #CRT; PAYMENT
	   print #CRT; "        The LAST PAYMENT will be   ";
	   print using MONEY.PRINT.FORMAT; #CRT; (PAYMENT + PRINCIPAL)
	   print #CRT; "        The TOTAL INTEREST PAID is ";
	   print using MONEY.PRINT.FORMAT; #CRT; (PAYMENT * TRANSACTIONS * LIFE.OF.LOAN)
	   print #CRT

	   RETURN.TO.MAIN.MENU

	end of CALC.INTEREST.LUMP.PRINCIPAL


	procedure CALC.PRINCIPAL.AND.INTEREST
	   comment
	      This module calculates the periodic interest payment due.  The
	      principal is paid in full at the end of the loan period.
	   end of comment


	   var  PAYMENT			;
	        LAST.PAYMENT		;
	        PRINCIPAL		;
	        BALLOON			;
	        BALLOON.INTEREST	;
	        BALANCE.MINUS.BALLOON	;
	        PRINCIPAL.AFTER.ONE	;
	           = real.double
	   var  INTEREST.RATE		;
	        LIFE.OF.LOAN		;
	        TRANSACTIONS		;
	        TOTAL.PAYMENT		;
	           = real.double
	   var  NUMBER.OF.PAYMENTS	;
	        INDEX			;
	        ARRAY.POINTER		;
	        LINE.POINTER		;
	           = integer
	   var  RESPONSE		;
	           = char

	   dim  real.double  BALANCE(MAX.ARRAY.SIZE)
	   dim  real.double  INTEREST(MAX.ARRAY.SIZE)
	   dim  real.double  PRINCIPAL.REDUCTION(MAX.ARRAY.SIZE)

	   print #CRT;"Loan Payment Calculator invoking Principal and Interest formula"
	   print #CRT

	   print #CRT; "        The interest compounding period is ";
	   PRINT.PERIOD  CRT, PERIOD.CHAR
	   print #CRT

	   PRINCIPAL = GET.REAL('P',0.0,100000000.00)
	   BALLOON = GET.REAL('B',0.0,100000000.00)
	   INTEREST.RATE = GET.REAL('R',0.0,1000.00) / 100.0
	   LIFE.OF.LOAN = GET.REAL('Y',0.0,1000.00)
	   TRANSACTIONS = GET.REAL('T',2.0,365.0)

	   remark  The loan calculations are computed using one formula set 
	   remark  for discrete compounding (Period char <> C) and another for
	   remark  continuous compounding

	   remark  Calculate the interest per period on the balloon payment

	   if (PERIOD.CHAR <> 'C')  then  BALLOON.INTEREST = BALLOON * (-1.0 + (1.0 + INTEREST.RATE / PERIOD)**(PERIOD / TRANSACTIONS))
	      else  BALLOON.INTEREST = BALLOON * (-1.0 + exp(INTEREST.RATE / TRANSACTIONS))


	   remark  Calculate the loan value after one period

	   BALANCE.MINUS.BALLOON = PRINCIPAL - BALLOON
	   if (PERIOD.CHAR <> 'C')  then  PRINCIPAL.AFTER.ONE = BALANCE.MINUS.BALLOON * ((1.0 + INTEREST.RATE / PERIOD)**(PERIOD / TRANSACTIONS))
	      else  PRINCIPAL.AFTER.ONE = BALANCE.MINUS.BALLOON * (exp(INTEREST.RATE / TRANSACTIONS))
	   BALANCE.MINUS.BALLOON = PRINCIPAL.AFTER.ONE

	   remark  Calculate the Periodic Payment amount

	   if (PERIOD.CHAR <> 'C')  then  PAYMENT = BALANCE.MINUS.BALLOON / ((1.0 - (1.0 + INTEREST.RATE / PERIOD)**(-1.0 * LIFE.OF.LOAN * PERIOD)) / (1.0 - (1.0 + INTEREST.RATE / PERIOD)**(-1.0 * PERIOD / TRANSACTIONS)))
	      else  PAYMENT = BALANCE.MINUS.BALLOON / ((1.0 - exp(-1.0 * INTEREST.RATE * LIFE.OF.LOAN)) / (1.0 - exp(-1.0 * INTEREST.RATE / TRANSACTIONS)))

	   PAYMENT = PAYMENT + BALLOON.INTEREST
	   BALANCE.MINUS.BALLOON = PRINCIPAL - BALLOON

	   remark  Calculate the Interest per Payment

	   NUMBER.OF.PAYMENTS = fix(TRANSACTIONS * LIFE.OF.LOAN + 0.4)

	   if (PERIOD.CHAR <> 'C')  then
	      begin  remark  Interest calculations not continuously compounded
	         for INDEX = 1 to NUMBER.OF.PAYMENTS
	            POSITION.CURSOR 14,0
	            print using PAYMENT.NUMBER.FORMAT ; #CRT; INDEX; NUMBER.OF.PAYMENTS;
	            INTEREST(INDEX) = BALANCE.MINUS.BALLOON * (-1.0 + (1.0 + INTEREST.RATE / PERIOD)**(PERIOD / TRANSACTIONS)) + BALLOON.INTEREST
	            PRINCIPAL.REDUCTION(INDEX) = PAYMENT - INTEREST(INDEX)
	            BALANCE.MINUS.BALLOON = BALANCE.MINUS.BALLOON - PRINCIPAL.REDUCTION(INDEX)
	            BALANCE(INDEX) = BALANCE.MINUS.BALLOON + BALLOON
	         next INDEX
	      end of if-then
	      else begin
	         for INDEX = 1 to NUMBER.OF.PAYMENTS
	            POSITION.CURSOR 14,0
	            print using PAYMENT.NUMBER.FORMAT; #CRT; INDEX; NUMBER.OF.PAYMENTS;
	            INTEREST(INDEX) = BALANCE.MINUS.BALLOON * (-1.0 + exp(INTEREST.RATE / TRANSACTIONS)) + BALLOON.INTEREST
	            PRINCIPAL.REDUCTION(INDEX) = PAYMENT - INTEREST(INDEX)
	            BALANCE.MINUS.BALLOON = BALANCE.MINUS.BALLOON - PRINCIPAL.REDUCTION(INDEX)
	            BALANCE(INDEX) = BALANCE.MINUS.BALLOON + BALLOON
	         next INDEX
	      end of if-else

	   PRINCIPAL.REDUCTION(NUMBER.OF.PAYMENTS) = BALANCE(NUMBER.OF.PAYMENTS - 1)
	   LAST.PAYMENT = INTEREST(NUMBER.OF.PAYMENTS) + BALANCE(NUMBER.OF.PAYMENTS - 1)
	   BALANCE(NUMBER.OF.PAYMENTS) = 0.0	   
	   TOTAL.PAYMENT = (PAYMENT + BALLOON.INTEREST) * (NUMBER.OF.PAYMENTS - 1) + LAST.PAYMENT

	   remark  Print Summary Calculations

	   POSITION.CURSOR 9,0
	   print #CRT
	   print #CRT; "        The TOTAL PAYMENT amounts to ";
	   print using MONEY.PRINT.FORMAT; #CRT; TOTAL.PAYMENT
	   print #CRT; "        The TOTAL INTEREST PAID is   ";
	   print using MONEY.PRINT.FORMAT; #CRT; TOTAL.PAYMENT - PRINCIPAL
	   print #CRT

	   remark  Print the Payment Table

	   print using TABLE.HEADER; #CRT
	   ARRAY.POINTER = 1

	   repeat
	      begin
	         POSITION.CURSOR 14,0
	         CLEAR.TO.END.OF.SCREEN
	         for INDEX = ARRAY.POINTER to (ARRAY.POINTER + 5)
	            if (INDEX < NUMBER.OF.PAYMENTS)  then
	               begin
	                  print using TABLE.LINE.FORMAT; #CRT; INDEX; PAYMENT; INTEREST(INDEX); PRINCIPAL.REDUCTION(INDEX); BALANCE(INDEX)
	               end of if-then
	            if (INDEX = NUMBER.OF.PAYMENTS)  then
	               begin
	                  print using TABLE.LINE.FORMAT; #CRT; INDEX; LAST.PAYMENT; INTEREST(INDEX); PRINCIPAL.REDUCTION(INDEX); BALANCE(INDEX)
	               end of if-then
	         next INDEX

	         remark  Get user's request for more data on display

	         repeat
	            begin
	               remark  turn off auto echo of user input
	               echo off

	               print #CRT
	               POSITION.CURSOR 21,0
	               CLEAR.TO.END.OF.SCREEN
	               input1 #CRT; "Type <F>orward, <R>everse, <P>ayment to scan, <H>ardcopy, or <E>xit"; RESPONSE;

	               remark  turn on auto echo of user input
	               echo on

	               RESPONSE = CONVERT.LOWER.TO.UPPER(RESPONSE)
	               if not CHECK.VALID.CHAR("FRPHEFRPEH",RESPONSE)  then
	                  RESPONSE = 'N'
	            end
	         until RESPONSE <> 'N'
	         case RESPONSE of
	            'F':  begin
	                     print #CRT; "Forward";
	                     ARRAY.POINTER = ((ARRAY.POINTER + 5) / 6) * 6 + 1
	                     if (ARRAY.POINTER > NUMBER.OF.PAYMENTS)  then   ARRAY.POINTER = 1
	                  end of case 'F'
	            'R':  begin
	                     print #CRT; "Reverse";
	                     ARRAY.POINTER = ((ARRAY.POINTER + 5) / 6) * 6 - 11
	                     if (ARRAY.POINTER < 1)  then  ARRAY.POINTER = ARRAY.POINTER + ((NUMBER.OF.PAYMENTS + 5) / 6) * 6
	                  end of case 'R'
	            'P':  begin
	                     print #CRT; "Payment"
	                     for INDEX = 1 to DELAY    remark  wait loop
	                     next INDEX
	                     repeat
	                        begin
	                           POSITION.CURSOR 21,0
	                           CLEAR.TO.END.OF.SCREEN
	                           print using REQUEST.NUMBER.FORMAT ; #CRT; NUMBER.OF.PAYMENTS;
	                           input3 #CRT; ARRAY.POINTER;
	                        end
	                     until CHECK.VALID.INTEGER.NUMBER(1,NUMBER.OF.PAYMENTS,ARRAY.POINTER)
	                  end of case 'P'
	            'H':  begin
	                     print #CRT; "Hardcopy"

	                     rem  Print heading user input
	                     print #PROWRITER; chr$(12); chr$(13); chr$(10); chr$(10); chr$(10); chr$(10); chr$(27); chr$(80)
	                     print #PROWRITER; chr$(14); "  Loan Payment Calculator Principal and Interest Results"; chr$(15)
	                     print #PROWRITER; chr$(10); chr$(10); chr$(10); chr$(27); chr$(69)

	                     remark  Print Summary Calculations
	                     print #PROWRITER
	                     print #PROWRITER; "        The AMOUNT BORROWED is ";
	                     print using MONEY.PRINT.FORMAT; #PROWRITER; PRINCIPAL
	                     print #PROWRITER; "        The INTEREST RATE is ";
	                     print using RATE.PRINT.FORMAT; #PROWRITER; (INTEREST.RATE * 100)
	                     print #PROWRITER; "        The INTEREST COMPOUNDING PERIOD is ";
	                     PRINT.PERIOD  PROWRITER, PERIOD.CHAR
	                     print #PROWRITER; "        The LIFE OF THE LOAN is ";
	                     print using YEARS.PRINT.FORMAT; #PROWRITER; LIFE.OF.LOAN
	                     print #PROWRITER; "        Number of PAYMENT PERIODS per year is "; TRANSACTIONS
	                     print #PROWRITER; "        The BALLOON PAYMENT is ";
	                     print using MONEY.PRINT.FORMAT; #PROWRITER; BALLOON
	                     print #PROWRITER
	                     print #PROWRITER; "        The TOTAL PAYMENT amounts to ";
	                     print using MONEY.PRINT.FORMAT; #PROWRITER; TOTAL.PAYMENT
	                     print #PROWRITER; "        The TOTAL INTEREST PAID is   ";
	                     print using MONEY.PRINT.FORMAT; #PROWRITER; TOTAL.PAYMENT - PRINCIPAL
	                     print #PROWRITER

	                     rem  Print the payment table
	                     for LINE.POINTER = 1 to NUMBER.OF.PAYMENTS
	                        if ((LINE.POINTER - (LINE.POINTER / 50) * 50) = 1)  then
	                           begin
	                              remark  Print table column headers
	                              print #PROWRITER; chr$(12); chr$(13); chr$(10); chr$(10); chr$(10); chr$(10)
	                              print #PROWRITER; chr$(27); chr$(33); space$(5);
	                              print using TABLE.HEADER; #PROWRITER
	                              print #PROWRITER; chr$(27); chr$(34)
	                           end
	                        if (LINE.POINTER < NUMBER.OF.PAYMENTS)  then
	                           begin
	                              print #PROWRITER; space$(5);
	                              print using TABLE.LINE.FORMAT; #PROWRITER; LINE.POINTER; \
	                                 PAYMENT; INTEREST(LINE.POINTER); \
	                                 PRINCIPAL.REDUCTION(LINE.POINTER); BALANCE(LINE.POINTER)
	                           end of if-then
	                        if (LINE.POINTER = NUMBER.OF.PAYMENTS)  then
	                           begin
	                              print #PROWRITER; space$(5);
	                              print using TABLE.LINE.FORMAT; #PROWRITER; LINE.POINTER; \
	                                 LAST.PAYMENT; INTEREST(LINE.POINTER); \
	                                 PRINCIPAL.REDUCTION(LINE.POINTER); BALANCE(LINE.POINTER)
	                           end of if-then
	                     next LINE.POINTER

	                  end of case 'H'
	            'E':  begin
	                     print #CRT; "Exit"
	                  end of case 'E'
	         end of case RESPONSE
	      end
	   until RESPONSE = 'E'

	   RETURN.TO.MAIN.MENU

	end of CALC.PRINCIPAL.AND.INTEREST


	procedure TERMINATE.LOAN
	   comment
	      This module closes off and exits from the LOAN
	      Program.
	   end of comment

	   print #CRT; "Loan Payment Calculator saying goodbye!"

	end of TERMINATE.LOAN


	begin
	   INTRO.TO.LOAN
	   repeat
	      begin
	         CALC.SELECTION = GET.CALCULATION.SELECTION
	         if ((CALC.SELECTION <> 'N') and (CALC.SELECTION <> 'E')) then
	            begin
	               repeat
	                  PERIOD.CHAR = GET.PERIOD.SELECTION
	               until PERIOD.CHAR <> 'N'
	               if ( PERIOD.CHAR = 'E' )  then  CALC.SELECTION = 'N'
	                  else  PERIOD = PERIOD.VALUE
	            end
	         case CALC.SELECTION of
	            'N':  remark  do nothing
	            'L':  CALC.INTEREST.PRINCIPAL.AT.END
	            'I':  CALC.INTEREST.LUMP.PRINCIPAL
	            'P':  CALC.PRINCIPAL.AND.INTEREST
	            'E':  remark  termination
	         end of case CALC.SELECTION
	      end 
	   until CALC.SELECTION = 'E'
	   TERMINATE.LOAN
	   stop
	end
t
	      